==> nextcloud-12.0.2.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/el.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Ομόσποσνδος διαμοιρασμός",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Θέλετε να προσθέσουμε τον απομακρυσμένο κοινόχρηστο φάκελο {name} από {owner}@{remote}?",
    "Remote share" : "Απομακρυσμένος κοινόχρηστος φάκελος",
    "Remote share password" : "Συνθηματικό απομακρυσμένου κοινόχρηστου φακέλου",
    "Cancel" : "Άκυρο",
    "Add remote share" : "Προσθήκη απομακρυσμένου κοινόχρηστου φακέλου",
    "Copy" : "Αντιγραφή",
    "Copied!" : "Αντιγράφτηκε!",
    "Not supported!" : "Δεν υποστηρίζεται!",
    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
    "Invalid Federated Cloud ID" : "Μη έγκυρο Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Ο διαμοιρασμός μεταξύ διακομιστών δεν έχει ενεργοποιηθεί σε αυτόν το διακομιστή",
    "Couldn't establish a federated share." : "Αδυναμία επίτευξης ομόσπονδου κοινόχρηστου φακέλου",
    "Couldn't establish a federated share, maybe the password was wrong." : "Δεν μπόρεσε να γίνει ένας federated διαμοιρασμός, μπορεί να ήταν λάθος το συνθηματικό",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Το αίτημα για Federate διαμοιρασμό εστάλη, θα λάβεις μια πρόσκληση. Έλεγξε τις ειδοποιήσεις.",
    "The mountpoint name contains invalid characters." : "Το σημείο προσάρτησης περιέχει μη έγκυρους χαρακτήρες.",
    "Not allowed to create a federated share with the owner." : "Δεν επιτρέπεται η δημιουργία federated διαμοιρασμού με τον ιδιοκτήτη",
    "Invalid or untrusted SSL certificate" : "Μη έγκυρο ή μη έμπιστο πιστοποιητικό SSL",
    "Could not authenticate to remote share, password might be wrong" : "Αδυναμία πιστοποίησης απομακρυσμένου κοινόχρηστου, το συνθηματικό μπορεί να είναι εσφαλμένο",
    "Storage not valid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Federated share added" : "O Federated διαμοιρασμός προστέθηκε",
    "Couldn't add remote share" : "Αδυναμία προσθήκης απομακρυσμένου κοινόχρηστου φακέλου",
    "Sharing %s failed, because this item is already shared with %s" : "Ο διαμοιρασμός του %s απέτυχε, γιατί το αντικείμενο είναι διαμοιρασμένο ήδη με τον χρήστη %s",
    "Not allowed to create a federated share with the same user" : "Δεν επιτρέπεται η δημιουργία federated διαμοιρασμού με τον ίδιο χρήστη",
    "File is already shared with %s" : "Το αρχείο είναι ήδη κοινόχρηστο με %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Η κοινή χρήση του %s απέτυχε, δεν ήταν δυνατή η εύρεση του %s, ίσως ο διακομιστής δεν είναι προσβάσιμος αυτήν τη στιγμή ή χρησιμοποιεί πιστοποιητικό που έχει υπογράψει αυτόματα.",
    "Could not find share" : "Αδυναμία εύρεσης κοινόχρηστου",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Διαμοιρασμός με εμένα μέσω του #Nextcloud Federated Cloud ID μου, δείτε %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Διαμοιρασμός με εμένα μέσω του #Nextcloud Federated Cloud ID μου",
    "Sharing" : "Διαμοιρασμός",
    "Federated file sharing" : "Federated διαμοιρασμός αρχείου",
    "Federated Cloud Sharing" : "Διαμοιρασμός Federated Cloud",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
    "Adjust how people can share between servers." : "Προσαρμόστε το πως τα άτομα θα διαμοιράζονται μεταξύ των διακομιστών",
    "Allow users on this server to send shares to other servers" : "Να επιτρέπεται σε χρήστες αυτού του διακομιστή να στέλνουν διαμοιρασμένους φακέλους σε άλλους διακομιστές",
    "Allow users on this server to receive shares from other servers" : "Να επιτρέπεται στους χρίστες του διακομιστή να λαμβάνουν διαμοιρασμένα αρχεία από άλλους διακομιστές",
    "Search global and public address book for users" : "Αναζήτηση σε γενικό και δημόσιο βιβλίο διευθύνσεων για χρήστες",
    "Allow users to publish their data to a global and public address book" : "Επιτρέψτε στους χρήστες να δημοσιεύουν τα δεδομένα τους σε ένα γενικό και δημόσιο βιβλίο διευθύνσεων",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Μπορείτε να διαμοιράζεστε με οποιονδήποτε χρησιμοποιεί Nextcloud, ownCloud η Pydio! Απλά προσθέστε το Federated Cloud ID στο πλαίσιο διαλόγου διαμοιρασμού. Θα μοιάζει με person@cloud.example.com",
    "Your Federated Cloud ID:" : "Το ID σας στο Federated Cloud:",
    "Share it so your friends can share files with you:" : "Διαμοιραστείτε το ώστε οι φίλοι σας να μπορούν να διαμοιράζονται αρχεία με εσάς:",
    "Add to your website" : "Προσθήκη στην ιστοσελίδα σας",
    "Share with me via Nextcloud" : "Διαμοιραστείτε με εμένα μέσω του Nextcloud",
    "HTML Code:" : "Κώδικας HTML:",
    "Search global and public address book for users and let local users publish their data" : "Αναζήτηση σε γενικό και δημόσιο βιβλίο διευθύνσεων για χρήστες και επιτρέψτε τους τοπικούς χρήστες να δημοσιεύουν τα δεδομένα τους",
    "Share it:" : "Μοιραστείτε το:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.14.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/el.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Θέλετε να προσθέσουμε τον απομακρυσμένο κοινόχρηστο φάκελο {name} από {owner}@{remote}?",
    "Remote share" : "Απομακρυσμένος κοινόχρηστος φάκελος",
    "Remote share password" : "Συνθηματικό απομακρυσμένου κοινόχρηστου φακέλου",
    "Cancel" : "Άκυρο",
    "Add remote share" : "Προσθήκη απομακρυσμένου κοινόχρηστου φακέλου",
    "Copy" : "Αντιγραφή",
    "Copied!" : "Αντιγράφτηκε!",
    "Not supported!" : "Δεν υποστηρίζεται!",
    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
    "Invalid Federated Cloud ID" : "Μη έγκυρο Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Ο διαμοιρασμός μεταξύ διακομιστών δεν έχει ενεργοποιηθεί σε αυτόν το διακομιστή",
    "Couldn't establish a federated share." : "Αδυναμία επίτευξης ομόσπονδου κοινόχρηστου φακέλου",
    "Couldn't establish a federated share, maybe the password was wrong." : "Δεν μπόρεσε να γίνει ένας federated διαμοιρασμός, μπορεί να ήταν λάθος το συνθηματικό",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Το αίτημα για Federate διαμοιρασμό εστάλη, θα λάβεις μια πρόσκληση. Έλεγξε τις ειδοποιήσεις.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Ο διαμοιρασμός του %1$s απέτυχε, γιατί το αντικείμενο είναι διαμοιρασμένο ήδη με τον χρήστη %2$s",
    "Not allowed to create a federated share with the same user" : "Δεν επιτρέπεται η δημιουργία federated διαμοιρασμού με τον ίδιο χρήστη",
    "File is already shared with %s" : "Το αρχείο είναι ήδη κοινόχρηστο με %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Η κοινή χρήση του %1$s απέτυχε, αδύνατη η εύρεση του %2$s, ίσως ο διακομιστής δεν είναι προσβάσιμος αυτήν τη στιγμή ή χρησιμοποιεί αυτό-υπογεγραμμένο πιστοποιητικό.",
    "Could not find share" : "Αδυναμία εύρεσης κοινόχρηστου",
    "Federated sharing" : "Ομόσποσνδος διαμοιρασμός",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Διαμοιρασμός με εμένα μέσω του #Nextcloud Federated Cloud ID μου, δείτε %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Διαμοιρασμός με εμένα μέσω του #Nextcloud Federated Cloud ID μου",
    "Sharing" : "Διαμοιρασμός",
    "Federated Cloud Sharing" : "Διαμοιρασμός Federated Cloud",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
    "Adjust how people can share between servers." : "Προσαρμόστε το πως τα άτομα θα διαμοιράζονται μεταξύ των διακομιστών",
    "Allow users on this server to send shares to other servers" : "Να επιτρέπεται σε χρήστες αυτού του διακομιστή να στέλνουν διαμοιρασμένους φακέλους σε άλλους διακομιστές",
    "Allow users on this server to receive shares from other servers" : "Να επιτρέπεται στους χρίστες του διακομιστή να λαμβάνουν διαμοιρασμένα αρχεία από άλλους διακομιστές",
    "Search global and public address book for users" : "Αναζήτηση σε γενικό και δημόσιο βιβλίο διευθύνσεων για χρήστες",
    "Allow users to publish their data to a global and public address book" : "Επιτρέψτε στους χρήστες να δημοσιεύουν τα δεδομένα τους σε ένα γενικό και δημόσιο βιβλίο διευθύνσεων",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Το ID σας στο Federated Cloud:",
    "Share it so your friends can share files with you:" : "Διαμοιραστείτε το ώστε οι φίλοι σας να μπορούν να διαμοιράζονται αρχεία με εσάς:",
    "Add to your website" : "Προσθήκη στην ιστοσελίδα σας",
    "Share with me via Nextcloud" : "Διαμοιραστείτε με εμένα μέσω του Nextcloud",
    "HTML Code:" : "Κώδικας HTML:"
},
"nplurals=2; plural=(n != 1);");
